==> nivo-0.15.0.tgz: package/es/components/tooltip/BasicTooltip.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import React from 'react';
import PropTypes from 'prop-types';
import pure from 'recompose/pure';

var tooltipStyle = {
    display: 'flex',
    alignItems: 'center'
};

var chipStyle = {
    display: 'block',
    width: '16px',
    height: '16px',
    marginRight: '9px',
    borderRadius: '2px'
};

var textStyle = {
    whiteSpace: 'pre'
};

var BasicTooltip = function BasicTooltip(_ref) {
    var id = _ref.id,
        value = _ref.value,
        enableChip = _ref.enableChip,
        color = _ref.color;
    return React.createElement(
        'div',
        { style: tooltipStyle },
        enableChip && React.createElement('span', { style: _extends({}, chipStyle, { background: color }) }),
        value !== undefined ? React.createElement(
            'span',
            { style: textStyle },
            id,
            ': ',
            React.createElement(
                'strong',
                null,
                value
            )
        ) : React.createElement(
            'span',
            { style: textStyle },
            id
        )
    );
};

BasicTooltip.propTypes = {
    id: PropTypes.oneOfType([PropTypes.string, PropTypes.number]).isRequired,
    value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    enableChip: PropTypes.bool.isRequired,
    color: PropTypes.string
};

BasicTooltip.defaultProps = {
    enableChip: false
};

export default pure(BasicTooltip);

==> nivo-0.19.0.tgz: package/es/components/tooltip/BasicTooltip.js <==
/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import React from 'react';
import PropTypes from 'prop-types';
import pure from 'recompose/pure';
import Chip from './Chip';

var tooltipStyle = {
    display: 'flex',
    alignItems: 'center'
};

var textStyle = {
    whiteSpace: 'pre',
    marginLeft: 7
};

var BasicTooltip = function BasicTooltip(_ref) {
    var id = _ref.id,
        value = _ref.value,
        enableChip = _ref.enableChip,
        color = _ref.color;
    return React.createElement(
        'div',
        { style: tooltipStyle },
        enableChip && React.createElement(Chip, { color: color }),
        value !== undefined ? React.createElement(
            'span',
            { style: textStyle },
            id,
            ': ',
            React.createElement(
                'strong',
                null,
                value
            )
        ) : React.createElement(
            'span',
            { style: textStyle },
            id
        )
    );
};

BasicTooltip.propTypes = {
    id: PropTypes.oneOfType([PropTypes.string, PropTypes.number]).isRequired,
    value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    enableChip: PropTypes.bool.isRequired,
    color: PropTypes.string
};

BasicTooltip.defaultProps = {
    enableChip: false
};

export default pure(BasicTooltip);
